@@ -1,7 +1,7 @@
 from typing import Mapping, TypeVar, Union
 
 from tgmount.vfs.types.dir import DirLike
-from tgmount.vfs.types.file import FileLike, FileContentString
+from tgmount.vfs.types.file import FileLike, FileContentStringProto
 
 T = TypeVar("T")
 
